@@ -8,10 +8,15 @@ from zope import schema
 from zope.component import adapter
 from zope.interface import implementer
 from zope.interface import provider
+from zope.interface import Interface
+
+
+class ILeadImage(Interface):
+    pass
 
 
 @provider(IFormFieldProvider)
-class ILeadImage(model.Schema):
+class ILeadImageBehavior(model.Schema):
 
     image = namedfile.NamedBlobImage(
         title=_(u'label_leadimage', default=u'Lead Image'),
@@ -26,9 +31,25 @@ class ILeadImage(model.Schema):
     )
 
 
-@implementer(ILeadImage)
+@implementer(ILeadImageBehavior)
 @adapter(IDexterityContent)
 class LeadImage(object):
 
     def __init__(self, context):
         self.context = context
+
+    @property
+    def image(self):
+        return self.context.image
+
+    @image.setter
+    def image(self, value):
+        self.context.image = value
+
+    @property
+    def image_caption(self):
+        return self.context.image_caption
+
+    @image_caption.setter
+    def image_caption(self, value):
+        self.context.image_caption = value
