@@ -9,11 +9,16 @@ from plone.dexterity.interfaces import IDexterityContent
 from plone.supermodel import model
 from zope.component import adapter
 from zope.interface import implementer
+from zope.interface import Interface
 from zope.interface import provider
 
 
+class IRichText(Interface):
+    pass
+
+
 @provider(IFormFieldProvider)
-class IRichText(model.Schema):
+class IRichTextBehavior(model.Schema):
 
     text = RichTextField(
         title=_(u'Text'),
@@ -24,13 +29,21 @@ class IRichText(model.Schema):
     model.primary('text')
 
 
-@implementer(IRichText)
+@implementer(IRichTextBehavior)
 @adapter(IDexterityContent)
 class RichText(object):
 
     def __init__(self, context):
         self.context = context
 
+    @property
+    def text(self):
+        return self.context.text
+
+    @text.setter
+    def text(self, value):
+        self.context.text = value
+
 
 class WidgetView(WidgetsView):
     schema = IRichText
