@@ -4,6 +4,7 @@ from plone.app.contenttypes.migration.field_migrators import datetime_fixer
 from plone.dexterity.interfaces import IDexterityContent
 from plone.dexterity.interfaces import IDexterityFTI
 from plone.event.utils import default_timezone
+from plone.folder.interfaces import IOrdering
 from Products.BTreeFolder2.BTreeFolder2 import BTreeFolder2Base
 from Products.CMFCore.utils import getToolByName
 from Products.contentmigration.basemigrator.migrator import CMFItemMigrator
@@ -12,6 +13,7 @@ from zExceptions import NotFound
 from zope.annotation.interfaces import IAnnotations
 from zope.component import queryUtility
 from zope.component.hooks import getSite
+from zope.interface import alsoProvides
 
 import importlib
 import logging
@@ -160,6 +162,7 @@ def migrate_base_class_to_new_class(obj,
     is_container = isinstance(obj, BTreeFolder2Base)
 
     if was_item and is_container or migrate_to_folderish and is_container:
+        alsoProvides(obj, IOrdering)
         #  If Itemish becomes Folderish we have to update obj _tree
         BTreeFolder2Base._initBTrees(obj)
 
