@@ -1,49 +1,50 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Migrating ATContentTypes to plone.app.contenttypes objects.
 
 This module imports from Product.contentmigration on which we depend
 only in the setuptools extra_requiers [migrate_atct]. Importing this
 module will only work if Products.contentmigration is installed so make sure
 you catch ImportErrors
-'''
+"""
+from plone.app.contenttypes.behaviors.collection import ICollection
+from plone.app.contenttypes.migration.dxmigration import DXEventMigrator
+from plone.app.contenttypes.migration.dxmigration import DXOldEventMigrator
+from plone.app.contenttypes.migration.field_migrators import FIELDS_MAPPING
+from plone.app.contenttypes.migration.field_migrators import migrate_blobimagefield  # noqa
+from plone.app.contenttypes.migration.field_migrators import migrate_datetimefield  # noqa
+from plone.app.contenttypes.migration.field_migrators import migrate_filefield
+from plone.app.contenttypes.migration.field_migrators import migrate_imagefield
+from plone.app.contenttypes.migration.field_migrators import migrate_richtextfield  # noqa
+from plone.app.contenttypes.migration.field_migrators import migrate_simplefield  # noqa
+from plone.app.contenttypes.migration.patches import patch_before_migration
+from plone.app.contenttypes.migration.patches import undo_patch_after_migration
+from plone.app.contenttypes.migration.utils import copy_contentrules
+from plone.app.contenttypes.migration.utils import migrate_leadimage
+from plone.app.contenttypes.migration.utils import migrate_portlets
+from plone.app.contenttypes.migration.utils import move_comments
+from plone.app.contenttypes.upgrades import LISTING_VIEW_MAPPING
+from plone.app.dexterity.behaviors.nextprevious import INextPreviousToggle
+from plone.dexterity.interfaces import IDexterityContent
+from plone.dexterity.interfaces import IDexterityFTI
 from Products.CMFCore.utils import getToolByName
 from Products.contentmigration.basemigrator.migrator import CMFFolderMigrator
 from Products.contentmigration.basemigrator.migrator import CMFItemMigrator
 from Products.contentmigration.basemigrator.walker import CatalogWalker
 from Products.contentmigration.walker import CustomQueryWalker
-from plone.app.contenttypes.behaviors.collection import ICollection
-from plone.app.contenttypes.migration.dxmigration import DXEventMigrator
-from plone.app.contenttypes.migration.dxmigration import DXOldEventMigrator
-from plone.app.contenttypes.migration.utils import copy_contentrules
-from plone.app.contenttypes.migration.utils import migrate_leadimage
-from plone.app.contenttypes.migration.utils import move_comments
-from plone.app.contenttypes.migration.utils import migrate_portlets
-from plone.app.contenttypes.migration.field_migrators import FIELDS_MAPPING
-from plone.app.contenttypes.migration.field_migrators import \
-    migrate_datetimefield
-from plone.app.contenttypes.migration.field_migrators import migrate_filefield
-from plone.app.contenttypes.migration.field_migrators import migrate_imagefield
-from plone.app.contenttypes.migration.field_migrators import \
-    migrate_blobimagefield
-from plone.app.contenttypes.migration.field_migrators import \
-    migrate_richtextfield
-from plone.app.contenttypes.migration.field_migrators import \
-    migrate_simplefield
-from plone.app.contenttypes.upgrades import LISTING_VIEW_MAPPING
-from plone.dexterity.interfaces import IDexterityContent
-from plone.dexterity.interfaces import IDexterityFTI
 from Acquisition import aq_base
 from zExceptions import NotFound
 from zope.component import adapter
 from zope.component import getAdapters
 from zope.component import getMultiAdapter
 from zope.component.hooks import getSite
-from zope.interface import Interface
 from zope.interface import implementer
+from zope.interface import Interface
+
 import logging
 import transaction
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -89,8 +90,11 @@ class ATCTContentMigrator(CMFItemMigrator):
     def __init__(self, *args, **kwargs):
         super(ATCTContentMigrator, self).__init__(*args, **kwargs)
         logger.info(
-            "Migrating {0}".format(
-                '/'.join(self.old.getPhysicalPath())))
+            'Migrating {0} {1}'.format(
+                self.old.portal_type,
+                '/'.join(self.old.getPhysicalPath())
+            )
+        )
 
     def beforeChange_store_default_page(self):
         """If the item is the default page store that info to set it again.
@@ -151,7 +155,10 @@ class ATCTFolderMigrator(CMFFolderMigrator):
     def __init__(self, *args, **kwargs):
         super(ATCTFolderMigrator, self).__init__(*args, **kwargs)
         logger.info(
-            "Migrating {}".format('/'.join(self.old.getPhysicalPath())))
+            'Migrating {0} {1}'.format(
+                self.old.portal_type,
+                '/'.join(self.old.getPhysicalPath()))
+        )
 
     def beforeChange_store_comments_on_portal(self):
         """Comments from plone.app.discussion are lost when the
@@ -180,6 +187,11 @@ class ATCTFolderMigrator(CMFFolderMigrator):
     def migrate_leadimage(self):
         migrate_leadimage(self.old, self.new)
 
+    def migrate_nextprevious(self):
+        if self.old.getNextPreviousEnabled():
+            if INextPreviousToggle.providedBy(self.new):
+                self.new.nextPreviousEnabled = True
+
     def last_migrate_comments(self):
         """Migrate the plone.app.discussion comments.
            Comments were stored on the portal, get them and
@@ -203,10 +215,10 @@ class ATCTFolderMigrator(CMFFolderMigrator):
             except AttributeError:
                 pass
             # always copy over the layout, transform if necessary
-            self.new.setLayout(LISTING_VIEW_MAPPING.get(old_layout, old_layout))   # noqa
+            self.new.setLayout(LISTING_VIEW_MAPPING.get(old_layout, old_layout))  # noqa
             if default_page:
                 # any defaultPage is switched of by setLayout
-                # and needs to set again
+                # and needs to set again if it was directly on the object
                 self.new.setDefaultPage(default_page)
 
 
@@ -371,7 +383,7 @@ class CollectionMigrator(ATCTContentMigrator):
         This needs to be done last, as otherwise our changes may get overriden
         by a later call to migrate_properties.
         """
-        old_layout = getattr(aq_base(self.old), 'layout', None)
+        old_layout = self.old.getLayout() or getattr(self.old, 'layout', None)
         if old_layout:
             try:
                 # Delete old-style layout attribute.
@@ -460,20 +472,31 @@ def makeCustomATMigrator(
             """
             if self.dry_run_mode:
                 view = getMultiAdapter(
-                    (self.new, self.new.REQUEST), name="view")
+                    (self.new, self.new.REQUEST), name='view')
                 view()
 
     return CustomATMigrator
 
 
-def migrateCustomAT(fields_mapping, src_type, dst_type, dry_run=False):
+def migrateCustomAT(fields_mapping,
+                    src_type,
+                    dst_type,
+                    dry_run=False,
+                    patch_linkintegrity=False,
+                    patch_searchabletext=False,
+                    ):
     """
-    Try to get types infos from archetype_tool, then set a migrator an pass it
+    Try to get types infos from archetype_tool, then set a migrator and pass it
     given values. There is a dry_run mode that allows to check the success of
     a migration without committing.
     """
     portal = getSite()
 
+    # Patch various things that make migration harder
+    (link_integrity,
+     queue_indexing,
+     patch_searchabletext) = patch_before_migration(patch_searchabletext)
+
     # if the type still exists get the src_meta_type from the portal_type
     portal_types = getToolByName(portal, 'portal_types')
     fti = portal_types.get(src_type, None)
@@ -495,8 +518,9 @@ def migrateCustomAT(fields_mapping, src_type, dst_type, dry_run=False):
                     brains[0].getURL())
                 return
             if IDexterityContent.providedBy(src_obj):
-                logger.error('%s should not be dexterity object!'
-                             % src_obj.absolute_url())
+                logger.error(
+                    '%s should not be dexterity object!',
+                    src_obj.absolute_url())
             is_folderish = getattr(src_obj, 'isPrincipiaFolderish', False)
             src_meta_type = src_obj.meta_type
     else:
@@ -516,6 +540,7 @@ def migrateCustomAT(fields_mapping, src_type, dst_type, dry_run=False):
                                     fields_mapping=fields_mapping,
                                     is_folderish=is_folderish,
                                     dry_run=dry_run)
+    walker_infos = None
     if migrator:
         migrator.src_meta_type = src_meta_type
         migrator.dst_meta_type = ''
@@ -537,4 +562,9 @@ def migrateCustomAT(fields_mapping, src_type, dst_type, dry_run=False):
             logger.error(error.get('message'))
         if dry_run:
             transaction.abort()
-        return walker_infos
+
+    # Revert to the original state
+    undo_patch_after_migration(
+        link_integrity, queue_indexing, patch_searchabletext)
+
+    return walker_infos
